brisk_it!() { /* proc-macro */ }Expand description
This macro is used to transform a brisk declarative representation into a state machine. Look at examples for usage.
brisk_it!() { /* proc-macro */ }This macro is used to transform a brisk declarative representation into a state machine. Look at examples for usage.